@@ -2,7 +2,7 @@ package Date::Holidays::TW;
 use strict;
 use utf8;
 
-our $VERSION = v0.7.0;
+our $VERSION = v0.8.0;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(is_tw_holiday tw_holidays);
@@ -1612,8 +1612,132 @@ my %CAL = (
         "1227" => "星期六、星期日",
         "1228" => "星期六、星期日",
     },
+
+    2026 => {
+        "0101" => "開國紀念日",
+        "0103" => "星期六、星期日",
+        "0104" => "星期六、星期日",
+        "0110" => "星期六、星期日",
+        "0111" => "星期六、星期日",
+        "0117" => "星期六、星期日",
+        "0118" => "星期六、星期日",
+        "0124" => "星期六、星期日",
+        "0125" => "星期六、星期日",
+        "0131" => "星期六、星期日",
+        "0201" => "星期六、星期日",
+        "0207" => "星期六、星期日",
+        "0208" => "星期六、星期日",
+        "0214" => "星期六、星期日",
+        "0215" => "小年夜",
+        "0216" => "農曆除夕",
+        "0217" => "春節",
+        "0218" => "春節",
+        "0219" => "春節",
+        "0220" => "補假",
+        "0221" => "星期六、星期日",
+        "0222" => "星期六、星期日",
+        "0227" => "補假",
+        "0228" => "和平紀念日",
+        "0301" => "星期六、星期日",
+        "0307" => "星期六、星期日",
+        "0308" => "星期六、星期日",
+        "0314" => "星期六、星期日",
+        "0315" => "星期六、星期日",
+        "0321" => "星期六、星期日",
+        "0322" => "星期六、星期日",
+        "0328" => "星期六、星期日",
+        "0329" => "星期六、星期日",
+        "0403" => "補假",
+        "0404" => "兒童節",
+        "0405" => "清明節",
+        "0406" => "補假",
+        "0411" => "星期六、星期日",
+        "0412" => "星期六、星期日",
+        "0418" => "星期六、星期日",
+        "0419" => "星期六、星期日",
+        "0425" => "星期六、星期日",
+        "0426" => "星期六、星期日",
+        "0501" => "勞動節",
+        "0502" => "星期六、星期日",
+        "0503" => "星期六、星期日",
+        "0509" => "星期六、星期日",
+        "0510" => "星期六、星期日",
+        "0516" => "星期六、星期日",
+        "0517" => "星期六、星期日",
+        "0523" => "星期六、星期日",
+        "0524" => "星期六、星期日",
+        "0530" => "星期六、星期日",
+        "0531" => "星期六、星期日",
+        "0606" => "星期六、星期日",
+        "0607" => "星期六、星期日",
+        "0613" => "星期六、星期日",
+        "0614" => "星期六、星期日",
+        "0619" => "端午節",
+        "0620" => "星期六、星期日",
+        "0621" => "星期六、星期日",
+        "0627" => "星期六、星期日",
+        "0628" => "星期六、星期日",
+        "0704" => "星期六、星期日",
+        "0705" => "星期六、星期日",
+        "0711" => "星期六、星期日",
+        "0712" => "星期六、星期日",
+        "0718" => "星期六、星期日",
+        "0719" => "星期六、星期日",
+        "0725" => "星期六、星期日",
+        "0726" => "星期六、星期日",
+        "0801" => "星期六、星期日",
+        "0802" => "星期六、星期日",
+        "0808" => "星期六、星期日",
+        "0809" => "星期六、星期日",
+        "0815" => "星期六、星期日",
+        "0816" => "星期六、星期日",
+        "0822" => "星期六、星期日",
+        "0823" => "星期六、星期日",
+        "0829" => "星期六、星期日",
+        "0830" => "星期六、星期日",
+        "0905" => "星期六、星期日",
+        "0906" => "星期六、星期日",
+        "0912" => "星期六、星期日",
+        "0913" => "星期六、星期日",
+        "0919" => "星期六、星期日",
+        "0920" => "星期六、星期日",
+        "0925" => "中秋節",
+        "0926" => "星期六、星期日",
+        "0927" => "星期六、星期日",
+        "0928" => "孔子誕辰紀念日/教師節",
+        "1003" => "星期六、星期日",
+        "1004" => "星期六、星期日",
+        "1009" => "補假",
+        "1010" => "國慶日",
+        "1011" => "星期六、星期日",
+        "1017" => "星期六、星期日",
+        "1018" => "星期六、星期日",
+        "1024" => "星期六、星期日",
+        "1025" => "臺灣光復暨金門古寧頭大捷紀念日",
+        "1026" => "補假",
+        "1031" => "星期六、星期日",
+        "1101" => "星期六、星期日",
+        "1107" => "星期六、星期日",
+        "1108" => "星期六、星期日",
+        "1114" => "星期六、星期日",
+        "1115" => "星期六、星期日",
+        "1121" => "星期六、星期日",
+        "1122" => "星期六、星期日",
+        "1128" => "星期六、星期日",
+        "1129" => "星期六、星期日",
+        "1205" => "星期六、星期日",
+        "1206" => "星期六、星期日",
+        "1212" => "星期六、星期日",
+        "1213" => "星期六、星期日",
+        "1219" => "星期六、星期日",
+        "1220" => "星期六、星期日",
+        "1225" => "行憲紀念日",
+        "1226" => "星期六、星期日",
+        "1227" => "星期六、星期日",
+    },
 );
 
+
 sub new { bless {}, shift };
 
 sub holidays {
